@@ -51,6 +51,10 @@ def _server_req(ticker, start, end, datatype):
     req.end = end
     req.datatype = datatype
 
+    if constants.API_KEY != "":
+        req.token = constants.API_KEY
+        req.username = constants.API_USERNAME
+
     res = _send_request(req)
 
     if res.code == 200:
@@ -64,7 +68,7 @@ def _server_req(ticker, start, end, datatype):
                 "Server returned invalid data") from exc
     else:
         raise errors.MoabRequestError(
-            "Server returned error code: " + str(res.code))
+            "Server returned error code " + str(res.code) + ": " + res.message)
 
 
 def get_equity(tickers, sample="1m",
